@@ -4,17 +4,17 @@
 # AUTHOR   : Richard Booth
 # DATE     : Sat Nov  9 11:18:04 2013
 # -----------------------------------------------------------------------------
-# NOTES    : 
+# NOTES    :
 #
 # LICENSE  : (BSD-new)
-# 
+#
 # This software is provided subject to the following terms and conditions,
 # which you should read carefully before using the software.  Using this
 # software indicates your acceptance of these terms and conditions.  If you
 # do not agree with these terms and conditions, do not use the software.
-# 
+#
 # Copyright (c) 2013 Richard Booth. All rights reserved.
-# 
+#
 # Redistribution and use in source or binary forms, with or without
 # modifications, are permitted provided that the following conditions are met:
 #     * Redistributions of source code must retain the above copyright
@@ -28,9 +28,9 @@
 #       (those who make changes to the software, documentation or other
 #       materials) may be used to endorse or promote products derived from
 #       this software without specific prior written permission.
-# 
+#
 # Disclaimer
-# 
+#
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, INFRINGEMENT AND THE IMPLIED WARRANTIES OF
 # MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
@@ -43,13 +43,13 @@
 # BUT NOT LIMITED TO, CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 # OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 # ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY
 # FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
 # ARISING OUT OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY
 # DERIVATIVES THEREOF, EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE
@@ -57,54 +57,52 @@
 # NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR
 # MODIFICATIONS.
 ################################################################################
-import user
-import decida
+from __future__ import print_function
+from builtins import zip
+from builtins import range
 import sys
-import os
-import os.path
-import string
-import re
-import numpy
-import math
-from Tkinter import *
-from decida.PlotBase import PlotBase
-from decida.Data import Data
+import decida
+from decida.PlotBasem import PlotBasem
 from decida.SelectionDialog import SelectionDialog
 
-class Contourx(PlotBase) :
-    """ plot line and color-band contours.
-
+class Contourx(PlotBasem) :
+    """
     **synopsis**:
 
-    Contourx plots color contour bands and/or contour lines of a 3-dimensional
-    surface specified on points on a 2-dimensional grid.  The color
-    bands can be hidden, leaving only the contour lines, or contour lines
-    can be hidden, leaving only the color bands.  The Edit->Settings 
-    dialog can be used to add more (equally-spaced) contour values.
+        Plot color-band and/or line contours.
+
+        Contourx plots color contour bands and/or contour lines of a
+        3-dimensional surface specified on points on a 2-dimensional grid.
+
+        The color bands can be hidden, leaving only the contour lines, or
+        contour lines can be hidden, leaving only the color bands.
+
+        The Edit->Settings dialog can be used to add more (equally-spaced)
+        contour values.
 
     **constructor arguments**:
 
-        .. option:: parent (Tkinter handle) (default=None)
+        **parent** (tk handle, default=None)
 
               handle of frame or other widget to pack plot in.
               if this is not specified, top-level is created.
 
-        .. option:: \*\*kwargs (dict)
+        **\*\*kwargs** (dict)
 
               keyword=value specifications:
-              options or configuration-options
+              **options** or **configuration-options**
 
     **options**:
 
-        .. option:: xvalues (list of float)
+        **xvalues** (list of float)
 
               list of x values. [x[0], ... , x[nx]]
 
-        .. option:: yvalues (list of float)
+        **yvalues** (list of float)
 
               list of y values. [y[0], ... , y[ny]]
 
-        .. option:: zvalues (list of lists of float)
+        **zvalues** (list of lists of float)
 
               list of z values corresponding x, y points
               [x[0],  y[0], ... , x[0],  y[ny]],
@@ -113,139 +111,136 @@ class Contourx(PlotBase) :
 
     **configuration options**:
 
-        .. option::  verbose (bool, default=False)
+        **verbose** (bool, default=False)
 
               enable/disable verbose mode
 
-        .. option::  title (str, default="")
+        **title** (str, default="")
 
               main title
 
-        .. option::  xtitle (str, default="")
+        **xtitle** (str, default="")
 
               x-axis title
 
-        .. option::  ytitle (str, default="")
+        **ytitle** (str, default="")
 
               y-axis title
 
-        .. option::  plot_height (str, default="10i" for MacOS, else "7i")
+        **plot_height** (str, default="10i" for MacOS, else "7i")
 
               Height of plot window (Tk inch  or pixelspecification)
 
-        .. option::  plot_width  (str, default="10i" for MacOS, else "7i")
+        **plot_width**  (str, default="10i" for MacOS, else "7i")
 
               Width of plot window (Tk inch or pixel specification)
 
-        .. option::  plot_background (str, default="GhostWhite")
+        **plot_background** (str, default="GhostWhite")
 
               Background color of plot window.
 
-        .. option::  legend_background (str, default="AntiqueWhite2")
+        **legend_background** (str, default="AntiqueWhite2")
 
               Background color of legend.
 
-        .. option::  grid_color (str, default="black")
+        **grid_color** (str, default="black")
 
               Color of contour grid.
 
-        .. option::  num_contours (int, default=21)
+        **num_contours** (int, default=21)
 
               number of contours.
 
-        .. option:: show_bands (bool, default=True)
+        **show_bands** (bool, default=True)
 
               if True, show contour color-bands.
 
-        .. option::  colors (list of str, default =
-                "blue", "red", "green", "orange", "cyan",
-                "brown", "black", "blue violet", "cadet blue",
-                "dark cyan", "dark goldenrod", "dark green",
-                "dark magenta", "dark olive green", "dark orange",
-                "dark red", "dark slate blue", "dark slate gray",
-                "dodger blue", "forest green", "steel blue", "sienna"
-              )
+        **colors** (list of str, default = ["blue", "red", "green",
+                 "orange", "cyan", "brown",
+                 "black", "blue violet", "cadet blue", "dark cyan",
+                 "dark goldenrod", "dark green", "dark magenta",
+                 "dark olive green", "dark orange", "dark red",
+                 "dark slate blue", "dark slate gray", "dodger blue",
+                 "forest green", "steel blue", "sienna"])
 
               list of colors for curves.
               Used to populate color menu, and to specify curve colors
               in scripted "command" option.
 
-        .. option::  symbols (list of str, default = 
-                "none", "dot", "square", "diamond",
-                "triangle", "itriangle",
+        **symbols** (list of str, default = ["none", "dot", "square",
+                "diamond", "triangle", "itriangle",
                 "dash", "pipe", "plus", "cross",
                 "spade", "heart", "diam", "club", "shamrock",
-                "fleurdelis", "circle", "star"
-              ) 
+                "fleurdelis", "circle", "star"])
 
               list of symbols for curves.
               Used to populate symbol menu, and to specify curve symbols
               in scripted "command" option.
 
-        .. option::  ssizes (list of floats, default = [0.01])
+        **ssizes** (list of float, default = [0.01])
 
               list of symbol sizes for curves.
               Used to specify curve symbol sizes
               in scripted "command" option.
 
-        .. option::  wlines (list of ints, default = [1])
+        **wlines** (list of int, default = [1])
 
               list of line widths for curves.
               Used to specify curve line widths
               in scripted "command" option.
 
-        .. option::  traces (list, default = ["increasing"])
+        **traces** (list of str, default = ["increasing"])
 
               list of traces for curves.  each trace can be one of:
               "increasing", "decreasing", or "both".
               Used to specify curve trace directions
               in scripted "command" option.
 
-        .. option::  xaxis (str, default="lin")
+        **xaxis** (str, default="lin")
 
               linear or logarithmic axis: "lin" or "log"
 
-        .. option::  yaxis (str, default="lin")
+        **yaxis** (str, default="lin")
 
               linear or logarithmic axis: "lin" or "log"
 
-        .. option::  xmin  (float, default=0.0)
+        **xmin**  (float, default=0.0)
 
               xaxis minimum
 
-        .. option::  xmax  (float, default=0.0)
+        **xmax**  (float, default=0.0)
 
               xaxis maximum
 
-        .. option::  ymin  (float, default=0.0)
+        **ymin**  (float, default=0.0)
 
               yaxis minimum
 
-        .. option::  ymax  (float, default=0.0)
+        **ymax**  (float, default=0.0)
 
               yaxis maximum
 
-        .. option::  grid  (bool, default=True)
+        **grid**  (bool, default=True)
 
               if true, show grid on plot
 
-        .. option::  legend  (bool, default=True)
+        **legend**  (bool, default=True)
 
               if true, show legend on plot
 
-        .. option::  postscript  (bool, default=False)
+        **postscript**  (bool, default=False)
 
               if true, generate a PostScript file.
 
-        .. option::  postscript_file (str, default="plot.ps")
+        **postscript_file** (str, default="plot.ps")
 
               name of PostScript file to plot to
 
-        .. option::  wait (bool, default=False)
+        **wait** (bool, default=False)
 
               wait in main-loop until window is destroyed.
 
-        .. option::  destroy (bool, default=False)
+        **destroy** (bool, default=False)
 
               destroy main window after it has been displayed.
               useful for displaying, generating PostScript, then
@@ -255,7 +250,7 @@ class Contourx(PlotBase) :
 
         import decida, math
         from decida.Contourx import Contourx
-        
+
         xmin, xmax, ymin, ymax, nx, ny, nc = -20, 20, -20, 20, 41, 41, 41
         def zfunction(x, y) :
             return math.pow(
@@ -275,18 +270,18 @@ class Contourx(PlotBase) :
 
     **public methods**:
 
-        * public methods from *PlotBase* (2-dimensinal plot base class)
+        * public methods from *PlotBasem* (2-dimensinal plot base class)
 
     """
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # Contourx main
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     #==========================================================================
     # METHOD  : __init__
     # PURPOSE : constructor
     #==========================================================================
     def __init__(self, parent=None, **kwargs) :
-        PlotBase.__init__(self, parent=parent)
+        PlotBasem.__init__(self, parent=parent, use_matplotlib=False)
         #----------------------------------------------------------------------
         # private variables:
         #----------------------------------------------------------------------
@@ -308,7 +303,7 @@ class Contourx(PlotBase) :
         #----------------------------------------------------------------------
         # keyword arguments are *not* all configuration options
         #----------------------------------------------------------------------
-        for key, value in kwargs.items() :
+        for key, value in list(kwargs.items()) :
             if   key == "xvalues" :
                 self._xvalues = value
             elif key == "yvalues" :
@@ -323,12 +318,12 @@ class Contourx(PlotBase) :
         #----------------------------------------------------------------------
         self._gui()
         self._mainloop()
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # Contourx configuration option callback methods
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # Contourx GUI
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     #==========================================================================
     # METHOD  : _contour_recalc
     # PURPOSE : re-calculate contours
@@ -411,9 +406,11 @@ class Contourx(PlotBase) :
                     )
                     zmin = min(z_list)
                     zmax = max(z_list)
-                    if zmin == zmax : continue
+                    if zmin == zmax :
+                        continue
                     if ((clo < zmin) and (chi < zmin)) or \
-                       ((clo > zmax) and (chi > zmax)) : continue
+                       ((clo > zmax) and (chi > zmax)) :
+                        continue
                     Dlo = []
                     Dhi = []
                     Llo = []
@@ -442,100 +439,100 @@ class Contourx(PlotBase) :
                             Hhi.append((m, Xhi[m], Yhi[m]))
                     coords = []
                     if (len(Hlo) < 2) and (len(Hhi) < 2) :
-                       #-----------------------------
-                       # fill entire grid section
-                       #-----------------------------
-                       if (clo <= zmin) and (chi >= zmax) :
-                           coords = [xo, yo, xo, yp, xp, yp, xp, yo]
+                        #-----------------------------
+                        # fill entire grid section
+                        #-----------------------------
+                        if (clo <= zmin) and (chi >= zmax) :
+                            coords = [xo, yo, xo, yp, xp, yp, xp, yo]
                     elif (len(Hlo) < 2) and (len(Hhi) == 2) :
-                       #-----------------------------
-                       # high band edge within segment
-                       #-----------------------------
-                       m1, x1, y1 = Hhi[0]
-                       m2, x2, y2 = Hhi[1]
-                       if (z_list[m1] == chi) :
-                           coords = [xo, yo, xo, yp, xp, yp, xp, yo]
-                       else :
-                           coords.extend((x1, y1))
-                           ccw = (z_list[m1] < chi)
-                           m = m1
-                           while m != m2 :
-                               if ccw :
-                                   x = (xo, xo, xp, xp)[m]
-                                   y = (yo, yp, yp, yo)[m]
-                                   m = (m-1) % 4
-                               else :
-                                   m = (m+1) % 4
-                                   x = (xo, xo, xp, xp)[m]
-                                   y = (yo, yp, yp, yo)[m]
-                               coords.extend((x, y))
-                           coords.extend((x2, y2))
+                        #-----------------------------
+                        # high band edge within segment
+                        #-----------------------------
+                        m1, x1, y1 = Hhi[0]
+                        m2, x2, y2 = Hhi[1]
+                        if (z_list[m1] == chi) :
+                            coords = [xo, yo, xo, yp, xp, yp, xp, yo]
+                        else :
+                            coords.extend((x1, y1))
+                            ccw = (z_list[m1] < chi)
+                            m = m1
+                            while m != m2 :
+                                if ccw :
+                                    x = (xo, xo, xp, xp)[m]
+                                    y = (yo, yp, yp, yo)[m]
+                                    m = (m-1) % 4
+                                else :
+                                    m = (m+1) % 4
+                                    x = (xo, xo, xp, xp)[m]
+                                    y = (yo, yp, yp, yo)[m]
+                                coords.extend((x, y))
+                            coords.extend((x2, y2))
                     elif (len(Hlo) == 2) and (len(Hhi) < 2) :
-                       #-----------------------------
-                       # low  band edge within segment
-                       #-----------------------------
-                       m1, x1, y1 = Hlo[0]
-                       m2, x2, y2 = Hlo[1]
-                       if (z_list[m1] == clo) :
-                           coords = [xo, yo, xo, yp, xp, yp, xp, yo]
-                       else :
-                           coords.extend((x1, y1))
-                           ccw = (z_list[m1] > clo)
-                           m = m1
-                           while m != m2 :
-                               if ccw :
-                                   x = (xo, xo, xp, xp)[m]
-                                   y = (yo, yp, yp, yo)[m]
-                                   m = (m-1) % 4
-                               else :
-                                   m = (m+1) % 4
-                                   x = (xo, xo, xp, xp)[m]
-                                   y = (yo, yp, yp, yo)[m]
-                               coords.extend((x, y))
-                           coords.extend((x2, y2))
+                        #-----------------------------
+                        # low  band edge within segment
+                        #-----------------------------
+                        m1, x1, y1 = Hlo[0]
+                        m2, x2, y2 = Hlo[1]
+                        if (z_list[m1] == clo) :
+                            coords = [xo, yo, xo, yp, xp, yp, xp, yo]
+                        else :
+                            coords.extend((x1, y1))
+                            ccw = (z_list[m1] > clo)
+                            m = m1
+                            while m != m2 :
+                                if ccw :
+                                    x = (xo, xo, xp, xp)[m]
+                                    y = (yo, yp, yp, yo)[m]
+                                    m = (m-1) % 4
+                                else :
+                                    m = (m+1) % 4
+                                    x = (xo, xo, xp, xp)[m]
+                                    y = (yo, yp, yp, yo)[m]
+                                coords.extend((x, y))
+                            coords.extend((x2, y2))
                     elif (len(Hlo) == 2) and (len(Hhi) == 2) :
-                       #-----------------------------
-                       # both band edges within segment
-                       #-----------------------------
-                       m1, x1, y1 = Hhi[0]
-                       m2, x2, y2 = Hhi[1]
-                       m3, x3, y3 = Hlo[0]
-                       m4, x4, y4 = Hlo[1]
-                       coords.extend((x1, y1))
-                       ccw = (z_list[m1] <= chi)
-                       m = m1
-                       while m != m3 and m != m4 :
-                           if ccw :
-                               x = (xo, xo, xp, xp)[m]
-                               y = (yo, yp, yp, yo)[m]
-                               m = (m-1) % 4
-                           else :
-                               m = (m+1) % 4
-                               x = (xo, xo, xp, xp)[m]
-                               y = (yo, yp, yp, yo)[m]
-                           coords.extend((x, y))
-                       if m == m3 :
-                           coords.extend((x3, y3, x4, y4))
-                           m = m4
-                       else :
-                           coords.extend((x4, y4, x3, y3))
-                           m = m3
-                       ccw = (z_list[m] >= clo)
-                       while m != m2 :
-                           if ccw :
-                               x = (xo, xo, xp, xp)[m]
-                               y = (yo, yp, yp, yo)[m]
-                               m = (m-1) % 4
-                           else :
-                               m = (m+1) % 4
-                               x = (xo, xo, xp, xp)[m]
-                               y = (yo, yp, yp, yo)[m]
-                           coords.extend((x, y))
-                       coords.extend((x2, y2))
+                        #-----------------------------
+                        # both band edges within segment
+                        #-----------------------------
+                        m1, x1, y1 = Hhi[0]
+                        m2, x2, y2 = Hhi[1]
+                        m3, x3, y3 = Hlo[0]
+                        m4, x4, y4 = Hlo[1]
+                        coords.extend((x1, y1))
+                        ccw = (z_list[m1] <= chi)
+                        m = m1
+                        while m != m3 and m != m4 :
+                            if ccw :
+                                x = (xo, xo, xp, xp)[m]
+                                y = (yo, yp, yp, yo)[m]
+                                m = (m-1) % 4
+                            else :
+                                m = (m+1) % 4
+                                x = (xo, xo, xp, xp)[m]
+                                y = (yo, yp, yp, yo)[m]
+                            coords.extend((x, y))
+                        if m == m3 :
+                            coords.extend((x3, y3, x4, y4))
+                            m = m4
+                        else :
+                            coords.extend((x4, y4, x3, y3))
+                            m = m3
+                        ccw = (z_list[m] >= clo)
+                        while m != m2 :
+                            if ccw :
+                                x = (xo, xo, xp, xp)[m]
+                                y = (yo, yp, yp, yo)[m]
+                                m = (m-1) % 4
+                            else :
+                                m = (m+1) % 4
+                                x = (xo, xo, xp, xp)[m]
+                                y = (yo, yp, yp, yo)[m]
+                            coords.extend((x, y))
+                        coords.extend((x2, y2))
                     else :
-                       print len(Hlo), len(Hhi)
-                    if len(coords) > 0 :
-                       self._contour_data.append((coords, color))
+                        print(len(Hlo), len(Hhi))
+                    if coords :
+                        self._contour_data.append((coords, color))
         #----------------------------------------------------------------------
         # generate line-segments for contours
         #----------------------------------------------------------------------
@@ -555,8 +552,10 @@ class Contourx(PlotBase) :
                     )
                     zmin = min(z_list)
                     zmax = max(z_list)
-                    if zmin == zmax : continue
-                    if (c < zmin) or (c > zmax) : continue
+                    if zmin == zmax :
+                        continue
+                    if (c < zmin) or (c > zmax) :
+                        continue
                     D = []
                     L = []
                     for zo, zp in zip(z_list[0:], z_list[1:]) :
@@ -574,14 +573,14 @@ class Contourx(PlotBase) :
                             self._curve_ydata[curve].extend((Y[m], Y[n]))
         #----------------------------------------------------------------------
         # sort segments (experimental)
-        # map x, y to node 
+        # map x, y to node
         #----------------------------------------------------------------------
         if False :
             Node = {}
             N_xy = {}
             n = -1
             for x, y in zip(self._curve_xdata[curve], self._curve_ydata[curve]) :
-                if not (x, y) in Node :
+                if (x, y) not in Node :
                     n += 1
                     Node[(x, y)] = n
                     N_xy[n] = (x, y)
@@ -589,7 +588,7 @@ class Contourx(PlotBase) :
     # METHOD  : _plot_curves
     # PURPOSE : plot all curves
     #==========================================================================
-    def _plot_curves(self) :
+    def _plot_curves(self, pairwise_coordinates=False) :
         plot = self._Component["plot"]
         ctag = "contours-BAND"
         for band in self._contour_data :
@@ -600,10 +599,10 @@ class Contourx(PlotBase) :
                 uvcoords.extend((u, v))
             plot.create_polygon(uvcoords, fill=color, tags=ctag)
         if self["show_bands"] :
-            plot.itemconfigure(ctag, state=NORMAL)
+            plot.itemconfigure(ctag, state="normal")
         else :
-            plot.itemconfigure(ctag, state=HIDDEN)
-        PlotBase._plot_curves(self, pairwise_coordinates=True)
+            plot.itemconfigure(ctag, state="hidden")
+        PlotBasem._plot_curves(self, pairwise_coordinates=True)
     #==========================================================================
     # METHOD  : _settings_cmd
     # PURPOSE : settings via entrytable-select
@@ -623,14 +622,14 @@ class Contourx(PlotBase) :
         #---------------------------------------------------------------------
         specs = [
           ["entry", "Titles", [
-                 ["title",  "Main title",   self["title"] ], 
+                 ["title",  "Main title",   self["title"] ],
                  ["xtitle", "X-axis title", self["xtitle"]],
                  ["ytitle", "Y-axis title", self["ytitle"]],
               ]
           ],
           ["entry", "Colors", [
-                 ["plot_bg",  "plot background",   self["plot_background"] ], 
-                 ["lgnd_bg",  "legend background", self["legend_background"] ], 
+                 ["plot_bg",  "plot background",   self["plot_background"] ],
+                 ["lgnd_bg",  "legend background", self["legend_background"] ],
               ]
           ],
           ["entry", "Contourx", [
@@ -646,7 +645,8 @@ class Contourx(PlotBase) :
               ]
           ],
         ]
-        sd = SelectionDialog(self, title="Plot Settings", guispecs=specs)
+        top = self._Component["top"]
+        sd = SelectionDialog(top, title="Plot Settings", guispecs=specs)
         V = sd.go()
         if V["ACCEPT"] :
             self["title"]             = V["title"]
