@@ -4,17 +4,17 @@
 # AUTHOR   : Richard Booth
 # DATE     : Sat Nov  9 11:20:03 2013
 # -----------------------------------------------------------------------------
-# NOTES    : 
+# NOTES    :
 #
 # LICENSE  : (BSD-new)
-# 
+#
 # This software is provided subject to the following terms and conditions,
 # which you should read carefully before using the software.  Using this
 # software indicates your acceptance of these terms and conditions.  If you
 # do not agree with these terms and conditions, do not use the software.
-# 
+#
 # Copyright (c) 2013 Richard Booth. All rights reserved.
-# 
+#
 # Redistribution and use in source or binary forms, with or without
 # modifications, are permitted provided that the following conditions are met:
 #     * Redistributions of source code must retain the above copyright
@@ -28,9 +28,9 @@
 #       (those who make changes to the software, documentation or other
 #       materials) may be used to endorse or promote products derived from
 #       this software without specific prior written permission.
-# 
+#
 # Disclaimer
-# 
+#
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, INFRINGEMENT AND THE IMPLIED WARRANTIES OF
 # MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
@@ -43,13 +43,13 @@
 # BUT NOT LIMITED TO, CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 # OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 # ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY
 # FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
 # ARISING OUT OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY
 # DERIVATIVES THEREOF, EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE
@@ -57,44 +57,50 @@
 # NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR
 # MODIFICATIONS.
 ################################################################################
-import string, re
+from __future__ import print_function
+from builtins import str
+from builtins import range
+from builtins import object
+import re
+import functools
 
-class EquationParser() :
-    """ equation parser class.
-    
+class EquationParser(object) :
+    """
     **synopsis**:
 
-    EquationParser parses a general algebraic equation, involving
-    numbers, variables, unary and binary operations, and parentheses.
-    It returns a set of simpler, parsed (space-separated) equations with
-    only 1, 2, or 3 token right-hand-side expressions: assignments, unary
-    operations, binary operations.
+        Equation parser class.
+
+        *EquationParser* parses a general algebraic equation, involving
+        numbers, variables, unary and binary operations, and parentheses.
+        It returns a set of simpler, parsed (space-separated) equations with
+        only 1, 2, or 3 token right-hand-side expressions: assignments, unary
+        operations, binary operations.
 
     **constructor arguments**:
 
-        .. option:: equation (string)
+        **equation** (str)
 
             lhs=rhs string to be parsed
 
-        .. option:: postfix (boolean) (optional, default=False)
+        **postfix** (bool, default=False)
 
             if True, generate postfix notation, otherwise infix
 
-        .. option:: varlist (list) (optional, default=None)
+        **varlist** (list of str, default=None)
 
             list of variables which are to be treated specially:
             if variable contains meta-character, it is replaced
             with a temporary name, then after parsing, re-replaced.
 
-        .. option:: debug (boolean) (optional, default=False)
+        **debug** (bool, default=False)
 
             if True, print out parsing information
 
-        .. option:: data_function_format (boolean) (default=True)
+        **data_function_format** (bool, default=True)
 
             if True, print out functions in Data-object-compatible
             format.
-  
+
     **operator precedence** (low to high)::
 
             && ||
@@ -148,17 +154,18 @@ class EquationParser() :
         self.__Key2Var = {}
         self.__debug   = debug
         self.__data_function_format = data_function_format
+        self.__equation_tokenized = ""
     #=========================================================================
     # METHOD: __tokenize
     #=========================================================================
     def __tokenize(self, line) :
         copy = line
-        line = string.strip(line)
+        line = line.strip()
         line = re.sub(" ", "", line)
         if self.__debug :
-            print "tokenize line:", line
+            print("tokenize line:", line)
         lout = []
-        while len(line) > 0 :
+        while line :
             m = re.search(EquationParser.ichk_re, line)
             if m :
                 word = m.group(1)
@@ -166,11 +173,10 @@ class EquationParser() :
                 n = len(word)
                 line = line[n:]
             else :
-                print "character \"%s\" not recognized in line:\n%s" % \
-                    (line[0], copy)
-                return
+                print("character \"%s\" not recognized in line:\n%s" % (line[0], copy))
+                return None
         if self.__debug :
-            print "tokenized:", lout
+            print("tokenized:", lout)
         return lout
     #==========================================================================
     # METHOD : __vars_sort
@@ -178,13 +184,13 @@ class EquationParser() :
     #==========================================================================
     def __vars_sort(self, var1, var2) :
         if   len(var1) > len(var2) :
-           return -1
+            return -1
         elif len(var1) < len(var2) :
-           return 1
+            return 1
         elif var1 > var2 :
-           return 1
+            return 1
         elif var1 < var2 :
-           return -1
+            return -1
         return 0
     #=========================================================================
     # METHOD: __map_vars
@@ -193,26 +199,26 @@ class EquationParser() :
     def __map_vars(self) :
         m=re.search("^([^=]+)=(.+)$", self.__equation)
         if not m :
-            print "equation not in right format: LHS = RHS"
-            return
+            print("equation not in right format: LHS = RHS")
+            return None
         lhs = m.group(1)
         rhs = m.group(2)
-        lhs = string.strip(lhs)
-        rhs = string.strip(rhs)
+        lhs = lhs.strip()
+        rhs = rhs.strip()
         if re.search("[/().-\[\]]", lhs):
             key  = self.__intvar()
             self.__Key2Var[key] = lhs
             lhs  = key
-        if not self.__varlist is None :
-            vars = self.__varlist
-            vars.sort(cmp=self.__vars_sort)
-            for i, var in enumerate(vars) :
+        if self.__varlist is not None :
+            var_list = self.__varlist
+            var_list.sort(key=functools.cmp_to_key(self.__vars_sort))
+            for i, var in enumerate(var_list) :
                 evar = re.escape(var)
                 if re.search("[/().-\[\]]", evar):
                     key  = self.__intvar()
                     self.__Key2Var[key] = var
                     if self.__debug :
-                        print "map %s to %s" % (var, key)
+                        print("map %s to %s" % (var, key))
                     rhs = re.sub(evar, key, rhs)
         return "%s=%s" % (lhs, rhs)
     #=========================================================================
@@ -221,13 +227,13 @@ class EquationParser() :
     def __unmap_vars(self) :
         olist = []
         for line in self.__result :
-           toks = string.split(line)
-           lout = []
-           for tok in toks :
-               if tok in self.__Key2Var :
-                   tok = self.__Key2Var[tok]
-               lout.append(tok)
-           olist.append(string.join(lout))
+            toks = line.split()
+            lout = []
+            for tok in toks :
+                if tok in self.__Key2Var :
+                    tok = self.__Key2Var[tok]
+                lout.append(tok)
+            olist.append(" ".join(lout))
         return olist
     #=========================================================================
     # METHOD: parse
@@ -246,7 +252,7 @@ class EquationParser() :
         line = self.__map_vars()
         self.__tokens = self.__tokenize(line)
         self.__tokens.append("\n")
-        self.__equation_tokenized = string.join(self.__tokens)
+        self.__equation_tokenized = " ".join(self.__tokens)
         self.__tok    = self.__tokens.pop(0)
         self.__assignment()
         return self.__unmap_vars()
@@ -265,9 +271,9 @@ class EquationParser() :
         """
         olist = []
         for line in self.__result :
-            toks = string.split(line)
+            toks = line.split()
             olist.append(toks[0])
-        if len(olist) > 0 :
+        if olist :
             olist.pop(-1)
         return olist
     #=========================================================================
@@ -282,54 +288,49 @@ class EquationParser() :
     def __isnum(self, s) :
         if re.search(EquationParser.num_re, s) :
             return True
-        else :
-            return False
+        return False
     #=========================================================================
     # METHOD: __issym
     #=========================================================================
     def __issym(self, s) :
         if re.search(EquationParser.sym_re, s) :
             return True
-        else :
-            return False
+        return False
     #=========================================================================
     # METHOD: __iszero
     #=========================================================================
     def __iszero(self, s) :
         if self.__isnum(s) :
             return eval("%s == 0.0" % (s))
-        else :
-            return False    
+        return False
     #=========================================================================
     # METHOD: __isone
     #=========================================================================
     def __isone(self, s) :
         if self.__isnum(s) :
             return eval("%s == 1.0" % (s))
-        else :
-            return False    
+        return False
     #=========================================================================
     # METHOD: __ishalf
     #=========================================================================
     def __ishalf(self, s) :
         if self.__isnum(s) :
             return eval("%s == 0.5" % (s))
-        else :
-            return False    
+        return False
     #=========================================================================
     # METHOD: __unop
     #=========================================================================
-    def __unop(self, a, op) :    
+    def __unop(self, a, op) :
         if   self.__isnum(a) :
             x = eval("%s %s" % (op, a))
             return str(x)
-        if len(string.split(a)) > 1:
+        if len(a.split()) > 1:
             a = "( %s )" % (a)
         return "%s %s" % (op, a)
     #=========================================================================
     # METHOD: __binop
     #=========================================================================
-    def __binop(self, a, b, op) :    
+    def __binop(self, a, b, op) :
         if   self.__isnum(a) and self.__isnum(b) :
             if op == "^" :
                 x = eval("pow(%s, %s)" % (a, b))
@@ -375,9 +376,9 @@ class EquationParser() :
                 return a
             elif self.__ishalf(b) :
                 return "sqrt ( %s ) " % (a)
-        if len(string.split(a)) > 1:
+        if len(a.split()) > 1:
             a = "( %s )" % (a)
-        if len(string.split(b)) > 1:
+        if len(b.split()) > 1:
             b = "( %s )" % (b)
         return "%s %s %s" % (a, op, b)
     #=========================================================================
@@ -386,7 +387,7 @@ class EquationParser() :
     def __expect(self, tok_expected) :
         ok = True
         if self.__debug :
-            print "expect %s see %s" % (tok_expected, self.__tok)
+            print("expect %s see %s" % (tok_expected, self.__tok))
         if   tok_expected == "number" :
             ok = self.__isnum(self.__tok)
         elif tok_expected == "symbol" :
@@ -394,9 +395,9 @@ class EquationParser() :
         else :
             ok = (self.__tok == tok_expected)
         if not ok :
-            print "expected %s but saw %s" % (tok_expected, self.__tok)
+            print("expected %s but saw %s" % (tok_expected, self.__tok))
         otok = self.__tok
-        if len(self.__tokens) > 0 :
+        if self.__tokens :
             self.__tok = self.__tokens.pop(0)
         else :
             self.__tok = ""
@@ -419,10 +420,10 @@ class EquationParser() :
             # eliminate lhs = intvar line
             #----------------------------------
             if len(self.__result) > 1 :
-                 self.__result.pop(-1)
-                 last = self.__result.pop(-1)
-                 rhs  = string.join(string.split(last)[2:])
-                 self.__result.append("%s = %s" % (lhs, rhs))
+                self.__result.pop(-1)
+                last = self.__result.pop(-1)
+                rhs  = " ".join(last.split()[2:])
+                self.__result.append("%s = %s" % (lhs, rhs))
     #=========================================================================
     # METHOD: __expression
     #=========================================================================
@@ -576,11 +577,11 @@ class EquationParser() :
                             x = args[1]
                             self.__result.append("%s = %s %s %s" % (lhs, y, fn, x))
                     else :
-                        args = string.join(args, ",")
+                        args = ",".join(args)
                         self.__result.append("%s = %s ( %s )" % (lhs, fn, args))
         elif self.__tok == "(" :
             self.__expect("(")
             self.__expression()
             self.__expect(")")
         else :
-            print "unexpected syntax in %s" % (self.__equation_tokenized)
+            print("unexpected syntax in %s" % (self.__equation_tokenized))
