@@ -4,17 +4,17 @@
 # AUTHOR   : Richard Booth
 # DATE     : Sat Nov  9 11:20:26 2013
 # -----------------------------------------------------------------------------
-# NOTES    : 
+# NOTES    :
 #
 # LICENSE  : (BSD-new)
-# 
+#
 # This software is provided subject to the following terms and conditions,
 # which you should read carefully before using the software.  Using this
 # software indicates your acceptance of these terms and conditions.  If you
 # do not agree with these terms and conditions, do not use the software.
-# 
+#
 # Copyright (c) 2013 Richard Booth. All rights reserved.
-# 
+#
 # Redistribution and use in source or binary forms, with or without
 # modifications, are permitted provided that the following conditions are met:
 #     * Redistributions of source code must retain the above copyright
@@ -28,9 +28,9 @@
 #       (those who make changes to the software, documentation or other
 #       materials) may be used to endorse or promote products derived from
 #       this software without specific prior written permission.
-# 
+#
 # Disclaimer
-# 
+#
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, INFRINGEMENT AND THE IMPLIED WARRANTIES OF
 # MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
@@ -43,13 +43,13 @@
 # BUT NOT LIMITED TO, CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 # OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 # ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY
 # FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
 # ARISING OUT OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY
 # DERIVATIVES THEREOF, EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE
@@ -57,69 +57,72 @@
 # NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR
 # MODIFICATIONS.
 ################################################################################
-import decida, re, string
+from __future__ import print_function
+from builtins import zip
+import re
+import decida
 from decida.ItclObjectx  import ItclObjectx
 from decida.LevMar       import LevMar
-from decida.DataViewx    import DataViewx 
 from decida.Parameters   import Parameters
-from decida.Data         import Data
-class Fitter(ItclObjectx) :
-    """ fit parameterized equation set to data.
 
+class Fitter(ItclObjectx) :
+    """
     **synopsis**:
 
-    Fitter is a wrapper around the Levenberg-Marquardt least-squares
-    optimization class LevMar.  One model equation set is specified, and one
-    parameter set is specified when the instance is created.
+        Fit parameterized equation set to data.
+
+        *Fitter* is a wrapper around the Levenberg-Marquardt least-squares
+        optimization class *LevMar*.  One model equation set is specified,
+        and one parameter set is specified when the instance is created.
 
     **constructor arguments**:
 
-        .. option:: model_eqns (string)
+        **model_eqns** (str)
 
            Set of equations involving data columns, and specified parameters
            equation set produces one data column, specified by the
            model_col configuration option.
 
-        .. option:: par_specs (string)
+        **par_specs** (str)
 
-           Set of specifications for a set of model parameters.  The 
+           Set of specifications for a set of model parameters.  The
            specifications are parameter name, initial value, the keyword
            *include* if the parameter is to be included in the optimization,
            lower_limit=value and upper_limit=value.  The last two
            specifications are optional, and if not specified the parameter
            is unbounded on the respective end.
 
-        .. option:: \*\*kwargs (dict)
+        **\*\*kwargs** (dict)
 
            keyword=value specifications:
            configuration-options
 
     **configuration options**:
 
-        .. option:: data (Data, default=None)
+        **data** (Data object handle, default=None)
 
            Data object which contains data to be fitted to the model equations.
            Model and residual columns are created in the Data object.
 
-        .. option:: meast_col (string, default="")
+        **meast_col** (str, default="")
 
            The data column which contains the data to be fitted.
 
-        .. option:: model_col (string, default="")
+        **model_col** (str, default="")
 
            The data column which is to be created to fit the meast_col data.
 
-        .. option:: error_col (string, default="")
+        **error_col** (str, default="")
 
            The relative or absolute error between the model_col
            and meast_col data
 
-        .. option:: residual  (string, default="relative")
+        **residual**  (str, default="relative")
 
            Specify whether residual is relative or absolute.  It must
            be one of these two values.
 
-        .. option:: quiet (bool, default=False)
+        **quiet** (bool, default=False)
 
            If True, do not print as much information from the LevMar class
            instance.
@@ -147,17 +150,17 @@ class Fitter(ItclObjectx) :
                 data=d
             )
             ftr.fit()
-            print ftr.par_values()
-            DataViewx(data=d, command=[["dt residual"], ["dt dicp dicp_mod"]])
+            print(ftr.par_values())
+            DataViewm(data=d, command=[["dt residual"], ["dt dicp dicp_mod"]])
 
     **public methods**:
 
         * public methods from *ItclObjectx*
 
     """
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # Fitter main
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     #==========================================================================
     # METHOD  : __init__
     # PURPOSE : constructor
@@ -182,16 +185,16 @@ class Fitter(ItclObjectx) :
         #----------------------------------------------------------------------
         # keyword arguments are all configuration options
         #----------------------------------------------------------------------
-        for key, value in kwargs.items() :
+        for key, value in list(kwargs.items()) :
             self[key] = value
         #----------------------------------------------------------------------
         # parameters
         #----------------------------------------------------------------------
         parobj_specs = []
-        for line in string.split(decida.interpolate(par_specs, 2), "\n") :
-            line = string.strip(line)
-            if len(line) > 0 :
-                items         = string.split(line)
+        for line in decida.interpolate(par_specs, 2).split("\n") :
+            line = line.strip()
+            if line :
+                items         = line.split()
                 name          = items.pop(0)
                 value         = float(items.pop(0))
                 include       = False
@@ -203,47 +206,42 @@ class Fitter(ItclObjectx) :
                     if item == "include" :
                         include = True
                     elif re.search("^lower_limit", item) :
-                        var, val = string.split(item, "=")
+                        var, val = item.split("=")
                         lower_limited=True
                         lower_limit = float(val)
                     elif re.search("^upper_limit", item) :
-                        var, val = string.split(item, "=")
+                        var, val = item.split("=")
                         upper_limited=True
                         upper_limit = float(val)
                 parobj_specs.append([name, value, include, lower_limited, upper_limited, lower_limit, upper_limit])
         self.__parobj = Parameters(specs=parobj_specs)
-        #----------------------------------------------------------------------
-        # create function with model equations
-        #----------------------------------------------------------------------
-        error=self["error_col"]
-        meast=self["meast_col"]
-        model=self["model_col"]
-        function_lines = []
-        function_lines.append("def model(p, d) :")
-        for par in self.__parobj.pars() :
-            function_lines.append("    %s = p[\"%s\"]" % (par, par))
-        for par in self.__parobj.pars() :
-            function_lines.append("    d.set(\"%s = $%s\")" % (par, par))
-        for eqn in string.split(model_eqns, "\n") :
-            eqn=string.strip(eqn)
-            if len(eqn) > 0 :
-                function_lines.append("    d.set(\"%s\")" % eqn)
-        function_lines.append("    d.set(\"%s = %s - %s\")" % \
-            (error, model, meast))
+        self.__model_eqns = decida.interpolate(model_eqns, 2)
+        self.__optobj = None
+    #----------------------------------------------------------------------
+    # optimization function
+    #----------------------------------------------------------------------
+    def model_function(self, parobj, datobj):
+        error_col = self["error_col"]
+        meast_col = self["meast_col"]
+        model_col = self["model_col"]
+        model_eqns = self.__model_eqns
+        for par in parobj.pars() :
+            value = parobj[par]
+            datobj.set("$par = $value")
+        for eqn in model_eqns.split("\n") :
+            eqn=eqn.strip()
+            if eqn :
+                datobj.set(eqn)
+        datobj.set("$error_col = $model_col - $meast_col")
         if self["residual"] == "relative" :
-            function_lines.append("    d.set(\"%s = %s / (%s + abs(%s))\")" % \
-                (error, error, 1e-18, meast))
-        lines = string.join(function_lines, "\n")
-        print lines
-        exec(lines)
-        self.__function = model
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+            datobj.set("$error_col = $error_col / (1e-18 + abs($meast_col))")
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # Fitter user commands
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-    #=========================================================================
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #==========================================================================
     # METHOD: fit
     # PURPOSE: fit data
-    #=========================================================================
+    #==========================================================================
     def fit(self) :
         """ fit the meast_col data to model equations.
 
@@ -254,7 +252,7 @@ class Fitter(ItclObjectx) :
 
         """
         self.__optobj = LevMar(
-            self.__function,
+            self.model_function,
             self.__parobj,
             self["data"],
             meast_col=self["meast_col"],
@@ -264,16 +262,16 @@ class Fitter(ItclObjectx) :
             debug=False
         )
         self.__optobj.fit()
-    #=========================================================================
+    #==========================================================================
     # METHOD: par_object
     # PURPOSE: return parameter object handle
-    #=========================================================================
+    #==========================================================================
     def par_object(self) :
         return self.__parobj
-    #=========================================================================
+    #==========================================================================
     # METHOD: par_reset
     # PURPOSE: reset parameter values to initial values
-    #=========================================================================
+    #==========================================================================
     def par_reset(self) :
         """ reset parameter values to initial values
 
@@ -283,10 +281,10 @@ class Fitter(ItclObjectx) :
 
         """
         self.__parobj.reset()
-    #=========================================================================
+    #==========================================================================
     # METHOD: par_values
     # PURPOSE: return parameter values
-    #=========================================================================
+    #==========================================================================
     def par_values(self) :
         """ return the current model parameter values.
 
@@ -296,11 +294,11 @@ class Fitter(ItclObjectx) :
               parameter values are in the same order as they were specified.
 
         """
-        return self.__parobj.values()
-    #=========================================================================
+        return list(self.__parobj.values())
+    #==========================================================================
     # METHOD: par_name_values
     # PURPOSE: return array of parameter name, value
-    #=========================================================================
+    #==========================================================================
     def par_name_values(self) :
         """ return array of parameter name, value
 
@@ -310,7 +308,7 @@ class Fitter(ItclObjectx) :
 
         """
         pars = self.__parobj.pars()
-        vals = self.__parobj.values()
+        vals = list(self.__parobj.values())
         return_array = {}
         for par, val in zip(pars, vals) :
             return_array[par] = val
