@@ -4,17 +4,17 @@
 # AUTHOR   : Richard Booth
 # DATE     : Sat Nov  9 11:20:58 2013
 # -----------------------------------------------------------------------------
-# NOTES    : 
+# NOTES    :
 #
 # LICENSE  : (BSD-new)
-# 
+#
 # This software is provided subject to the following terms and conditions,
 # which you should read carefully before using the software.  Using this
 # software indicates your acceptance of these terms and conditions.  If you
 # do not agree with these terms and conditions, do not use the software.
-# 
+#
 # Copyright (c) 2013 Richard Booth. All rights reserved.
-# 
+#
 # Redistribution and use in source or binary forms, with or without
 # modifications, are permitted provided that the following conditions are met:
 #     * Redistributions of source code must retain the above copyright
@@ -28,9 +28,9 @@
 #       (those who make changes to the software, documentation or other
 #       materials) may be used to endorse or promote products derived from
 #       this software without specific prior written permission.
-# 
+#
 # Disclaimer
-# 
+#
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, INFRINGEMENT AND THE IMPLIED WARRANTIES OF
 # MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
@@ -43,13 +43,13 @@
 # BUT NOT LIMITED TO, CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 # OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 # ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY
 # FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
 # ARISING OUT OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY
 # DERIVATIVES THEREOF, EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE
@@ -57,46 +57,44 @@
 # NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR
 # MODIFICATIONS.
 ################################################################################
-import user
-import sys
-import os
-import os.path
-import string
-import re
+from builtins import zip
+from builtins import range
+import six
 import numpy
-from decida.PlotBase import PlotBase
+from decida.PlotBasem import PlotBasem
 from decida.Data import Data
 from decida.SelectionDialog import SelectionDialog
 
-class Histogramx(PlotBase) :
-    """ plot histogram of vector values.
-
+class Histogramx(PlotBasem) :
+    """
     **synopsis**:
 
-    Histogramx plots a histogram of counts of a 1-dimensional array of values.
-    For each data value, if it is within the range of a particular histogram
-    bin, that bin's count is incremented.  The set of histogram bins are
-    specified by configuration options, but can be changed by using the 
-    Edit->Settings dialog.
+        Plot histogram of vector values.
+
+        *Histogramx* plots a histogram of counts of a 1-dimensional array
+        of values.  For each data value, if it is within the range of a
+        particular histogram bin, that bin's count is incremented.
+
+        The set of histogram bins are specified by configuration options,
+        but can be changed by using the Edit->Settings dialog.
 
     **constructor arguments**:
 
-        .. option:: parent (Tkinter handle) (default=None)
+        **parent** (tk handle, default=None)
 
               handle of frame or other widget to pack plot in.
               if this is not specified, top-level is created.
 
-        .. option:: \*\*kwargs (dict)
+        **\*\*kwargs** (dict)
 
               keyword=value specifications:
               options or configuration-options
 
     **options**:
 
-        .. option:: command 
+        **command** (list)
 
-              list of pairs of data-object, string of x, ?x1, x2, ...?
-              columns
+              list of pairs of data-object, string of x, ?x1, x2, ...? columns
 
               example: [d1, "x x1 x2", d2, "x x1 x2"]:
                  x, x1, and x2 histograms will be plotted for each
@@ -108,147 +106,145 @@ class Histogramx(PlotBase) :
 
     **configuration options**:
 
-        .. option::  verbose (bool, default=False)
+        **verbose** (bool, default=False)
 
               enable/disable verbose mode
 
-        .. option::  title (str, default="")
+        **title** (str, default="")
 
               main title
 
-        .. option::  xtitle (str, default="")
+        **xtitle** (str, default="")
 
               x-axis title
 
-        .. option::  ytitle (str, default="")
+        **ytitle** (str, default="")
 
               y-axis title
 
-        .. option::  plot_height (str, default="10i" for MacOS, else "6i")
+        **plot_height** (str, default="10i" for MacOS, else "6i")
 
               Height of plot window (Tk inch  or pixelspecification)
 
-        .. option::  plot_width  (str, default="10i" for MacOS, else "6i")
+        **plot_width**  (str, default="10i" for MacOS, else "6i")
 
               Width of plot window (Tk inch or pixel specification)
 
-        .. option::  plot_background (str, default="GhostWhite")
+        **plot_background** (str, default="GhostWhite")
 
               Background color of plot window
 
-        .. option::  legend_background (str, default="AntiqueWhite2")
+        **legend_background** (str, default="AntiqueWhite2")
 
               Background color of legend
 
-        .. option::  nbins (int, default=21)
+        **nbins** (int, default=21)
 
               number of histogram bins between binorigin and nbins*binsize.
 
-        .. option:: binsize (float, default=1.0)
+        **binsize** (float, default=1.0)
 
               size of each histogram bin.
 
-        .. option:: binorigin (float, default=0.0)
+        **binorigin** (float, default=0.0)
 
               minimum of histogram bins.
 
-        .. option:: bar_width (float, default=1.0)
+        **bar_width** (float, default=1.0)
 
               width of each histogram bar.
 
-        .. option:: bar_outline (str, default="black")
+        **bar_outline** (str, default="black")
 
               color or each histogram bar.
 
-        .. option::  colors (list of str, default =
+        **colors** (list of str, default = [
                 "blue", "red", "green", "orange", "cyan",
                 "brown", "black", "blue violet", "cadet blue",
                 "dark cyan", "dark goldenrod", "dark green",
                 "dark magenta", "dark olive green", "dark orange",
                 "dark red", "dark slate blue", "dark slate gray",
-                "dodger blue", "forest green", "steel blue", "sienna"
-              )
+                "dodger blue", "forest green", "steel blue", "sienna"])
 
               list of colors for curves.
               Used to populate color menu, and to specify curve colors
               in scripted "command" option.
 
-        .. option::  symbols (list of str, default = 
+        **symbols** (list of str, default = [
                 "none", "dot", "square", "diamond",
                 "triangle", "itriangle",
                 "dash", "pipe", "plus", "cross",
                 "spade", "heart", "diam", "club", "shamrock",
-                "fleurdelis", "circle", "star"
-              ) 
+                "fleurdelis", "circle", "star"])
 
               list of symbols for curves.
               Used to populate symbol menu, and to specify curve symbols
               in scripted "command" option.
 
-        .. option::  ssizes (list of floats, default = [0.01])
+        **ssizes** (list of float, default = [0.01])
 
               list of symbol sizes for curves.
               Used to specify curve symbol sizes
               in scripted "command" option.
 
-        .. option::  wlines (list of ints, default = [1])
+        **wlines** (list of int, default = [1])
 
               list of line widths for curves.
               Used to specify curve line widths
               in scripted "command" option.
 
-        .. option::  traces (list, default = ["increasing"])
+        **traces** (list, default = ["increasing"])
 
               list of traces for curves.  each trace can be one of:
               "increasing", "decreasing", or "both".
               Used to specify curve trace directions
               in scripted "command" option.
 
-        .. option::  xaxis (str, default="lin")
+        **xaxis** (str, default="lin")
 
               linear or logarithmic axis: "lin" or "log"
 
-        .. option::  yaxis (str, default="lin")
+        **yaxis** (str, default="lin")
 
               linear or logarithmic axis: "lin" or "log"
 
-        .. option::  xmin  (float, default=0.0)
+        **xmin**  (float, default=0.0)
 
               xaxis minimum
 
-        .. option::  xmax  (float, default=0.0)
+        **xmax**  (float, default=0.0)
 
               xaxis maximum
 
-        .. option::  ymin  (float, default=0.0)
+        **ymin**  (float, default=0.0)
 
               yaxis minimum
 
-        .. option::  ymax  (float, default=0.0)
+        **ymax**  (float, default=0.0)
 
               yaxis maximum
 
-        .. option::  grid  (bool, default=True)
+        **grid**  (bool, default=True)
 
               if true, show grid on plot
 
-        .. option::  legend  (bool, default=True)
+        **legend**  (bool, default=True)
 
               if true, show legend on plot
 
-        .. option::  postscript  (bool, default=False)
+        **postscript**  (bool, default=False)
 
               if true, generate a PostScript file.
 
-        .. option::  postscript_file (str, default="plot.ps")
+        **postscript_file** (str, default="plot.ps")
 
               name of PostScript file to plot to
 
-        .. option::  wait (bool, default=False)
+        **wait** (bool, default=False)
 
               wait in main-loop until window is destroyed.
 
-        .. option::  destroy (bool, default=False)
+        **destroy** (bool, default=False)
 
               destroy main window after it has been displayed.
               useful for displaying, generating PostScript, then
@@ -264,18 +260,18 @@ class Histogramx(PlotBase) :
 
     **public methods**:
 
-        * public methods from *PlotBase* (2-dimensinal plot base class)
+        * public methods from *PlotBasem* (2-dimensinal plot base class)
 
     """
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # Histogramx main
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     #==========================================================================
     # METHOD  : __init__
     # PURPOSE : constructor
     #==========================================================================
     def __init__(self, parent=None, **kwargs) :
-        PlotBase.__init__(self, parent=parent)
+        PlotBasem.__init__(self, parent=parent, use_matplotlib=False)
         #----------------------------------------------------------------------
         # private variables:
         #----------------------------------------------------------------------
@@ -292,7 +288,7 @@ class Histogramx(PlotBase) :
         #----------------------------------------------------------------------
         # keyword arguments are *not* all configuration options
         #----------------------------------------------------------------------
-        for key, value in kwargs.items() :
+        for key, value in list(kwargs.items()) :
             if key == "command" :
                 command = value
             else :
@@ -311,8 +307,8 @@ class Histogramx(PlotBase) :
                 idata += 1
                 datobj = item
                 dname = "data_%d" % (idata)
-            elif type(item) == str :
-                cols = string.split(item)
+            elif isinstance(item, six.string_types):
+                cols = item.split()
                 for col in cols:
                     hset = "%s:%s" % (dname, col)
                     self.__hsets.append(hset)
@@ -325,36 +321,38 @@ class Histogramx(PlotBase) :
         #----------------------------------------------------------------------
         self._gui()
         self._mainloop()
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # Histogramx configuration option callback methods
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-    #===========================================================================
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #==========================================================================
     # METHOD  : _config_nbins_callback
     # PURPOSE : number of histogram bins
-    #===========================================================================
+    #==========================================================================
     def _config_nbins_callback(self) :
         nbins = self["nbins"]
         if nbins <= 0:
             self.warning("number of bins must be > 0")
             return False
-    #===========================================================================
+        return True
+    #==========================================================================
     # METHOD  : _config_binsize_callback
     # PURPOSE : size of histogram bins
-    #===========================================================================
+    #==========================================================================
     def _config_binsize_callback(self) :
         binsize = self["binsize"]
         if binsize <= 0.0:
             self.warning("bin size must be > 0")
             return False
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+        return True
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # Histogramx GUI
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     #==========================================================================
     # METHOD  : _gui
     # PURPOSE : build graphical user interface
     #==========================================================================
     def _gui(self) :
-        PlotBase._gui(self)
+        PlotBasem._gui(self)
         func0 = self._Component["func0"]
         func1 = self._Component["func1"]
         func0.configure(text="", command="", variable="")
@@ -370,9 +368,9 @@ class Histogramx(PlotBase) :
         for index in range(0, end+1) :
             try :
                 lab = edit_menu.entryconfig(index, "label")[4]
-                if type(lab) is tuple :
-                    lab = string.join(lab)
-                if not lab in keeps :
+                if isinstance(lab, tuple):
+                    lab = " ".join(lab)
+                if lab not in keeps :
                     dels.append(lab)
             except :
                 pass
@@ -459,7 +457,7 @@ class Histogramx(PlotBase) :
     # METHOD  : _plot_curves
     # PURPOSE : plot all curves
     #==========================================================================
-    def _plot_curves(self) :
+    def _plot_curves(self, pairwise_coordinates=False) :
         plot = self._Component["plot"]
         hbar_width = 0.5*self["bar_width"]
         s1, t = self.plot_xy_st(0,0)
@@ -473,7 +471,7 @@ class Histogramx(PlotBase) :
         for curve in self.curves() :
             color = self._curve_color[curve]
             wline = self._curve_wline[curve]
-            xydata = zip(self._curve_xdata[curve], self._curve_ydata[curve])
+            xydata = list(zip(self._curve_xdata[curve], self._curve_ydata[curve]))
             ltag = curve + "-LINE"
             for x, y in xydata :
                 sh, th = self.plot_xy_st(x, y)
@@ -510,14 +508,14 @@ class Histogramx(PlotBase) :
         #---------------------------------------------------------------------
         specs = [
           ["entry", "Titles", [
-                 ["title",  "Main title",   self["title"] ], 
+                 ["title",  "Main title",   self["title"] ],
                  ["xtitle", "X-axis title", self["xtitle"]],
                  ["ytitle", "Y-axis title", self["ytitle"]],
               ]
           ],
           ["entry", "Colors", [
-                 ["plot_bg",  "plot background",   self["plot_background"] ], 
-                 ["lgnd_bg",  "legend background", self["legend_background"] ], 
+                 ["plot_bg",  "plot background",   self["plot_background"] ],
+                 ["lgnd_bg",  "legend background", self["legend_background"] ],
               ]
           ],
           ["entry", "Histogramx", [
@@ -533,7 +531,8 @@ class Histogramx(PlotBase) :
               ]
           ],
         ]
-        sd = SelectionDialog(self, title="Plot Settings", guispecs=specs)
+        top = self._Component["top"]
+        sd = SelectionDialog(top, title="Plot Settings", guispecs=specs)
         V = sd.go()
         if V["ACCEPT"] :
             self["title"]             = V["title"]
@@ -544,7 +543,7 @@ class Histogramx(PlotBase) :
             self["nbins"]             = int(V["nbins"])
             self["binorigin"]         = float(V["binorigin"])
             #-----------------------------------------
-            # if binsize wasn't changed, revise 
+            # if binsize wasn't changed, revise
             #-----------------------------------------
             if self["binsize"]   == float(V["binsize"]) :
                 nbins                 = self["nbins"]
