@@ -4,17 +4,17 @@
 # AUTHOR   : Richard Booth
 # DATE     : Sat Nov  9 11:22:47 2013
 # -----------------------------------------------------------------------------
-# NOTES    : 
+# NOTES    :
 #
 # LICENSE  : (BSD-new)
-# 
+#
 # This software is provided subject to the following terms and conditions,
 # which you should read carefully before using the software.  Using this
 # software indicates your acceptance of these terms and conditions.  If you
 # do not agree with these terms and conditions, do not use the software.
-# 
+#
 # Copyright (c) 2013 Richard Booth. All rights reserved.
-# 
+#
 # Redistribution and use in source or binary forms, with or without
 # modifications, are permitted provided that the following conditions are met:
 #     * Redistributions of source code must retain the above copyright
@@ -28,9 +28,9 @@
 #       (those who make changes to the software, documentation or other
 #       materials) may be used to endorse or promote products derived from
 #       this software without specific prior written permission.
-# 
+#
 # Disclaimer
-# 
+#
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, INFRINGEMENT AND THE IMPLIED WARRANTIES OF
 # MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
@@ -43,13 +43,13 @@
 # BUT NOT LIMITED TO, CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 # OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 # ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY
 # FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
 # ARISING OUT OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY
 # DERIVATIVES THEREOF, EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE
@@ -57,37 +57,42 @@
 # NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR
 # MODIFICATIONS.
 ################################################################################
-import user, math
+from __future__ import print_function
+from builtins import zip
+import math
 from decida.Parameter   import Parameter
 from decida.ItclObjectx import ItclObjectx
 
 class Parameters(ItclObjectx) :
-    """ parameter set manager class.
-
+    """
     **synopsis**:
 
-    *Parameters* manages a set of instances of the *Parameter* class.
-    Each *Parameter* instance has associated current value and ranges.
+        Parameter set manager class.
 
-    *LevMar* and *Fitter* use the *Parameters* instance to manage
-    the optimization.
+        *Parameters* manages a set of instances of the *Parameter* class.
+        Each *Parameter* instance has associated current value and ranges.
+
+        *LevMar* and *Fitter* use the *Parameters* instance to manage
+        the optimization.
 
     **constructor arguments**:
 
-        .. option:: \*\*kwargs (dict)
+        **\*\*kwargs** (dict)
 
               keyword=value specifications:
               configuration-options
 
     **configuration options**:
 
-        .. option:: verbose (bool, default=False)
+        **verbose** (bool, default=False)
 
-        .. option:: gui (bool, default=True)
+            If verbose is True, print more information if available.
+
+        **gui** (bool, default=True)
 
             flag to indicate that a *Parameters* graphical user-interface
             should be displayed. **Not currently implemented**
- 
+
     **example** (from test_Parameters): ::
 
         from decida.Parameters import Parameters
@@ -232,7 +237,7 @@ class Parameters(ItclObjectx) :
         #----------------------------------------------------------------------
         # keyword arguments are all configuration options
         #----------------------------------------------------------------------
-        for key, value in kwargs.items() :
+        for key, value in list(kwargs.items()) :
             self[key] = value
         #----------------------------------------------------------------------
         # add any parameters from specs
@@ -264,9 +269,8 @@ class Parameters(ItclObjectx) :
             return ItclObjectx.__getitem__(self, item)
         elif item in self.__parameters :
             return self.__ParHandle[item]["current_value"]
-        else :
-            self.warning("config option or parameter \"%s\" not present" % (item))
-            return
+        self.warning("config option or parameter \"%s\" not present" % (item))
+        return None
     #==========================================================================
     # METHOD  : __setitem__
     # PURPOSE : return config option or parameter value
@@ -288,7 +292,7 @@ class Parameters(ItclObjectx) :
 
         **arguments**:
 
-            .. option:: par (string, default=None)
+            **par** (str, default=None)
 
                 parameter name to show.  If not specified, all parameters are
                 shown.
@@ -299,15 +303,15 @@ class Parameters(ItclObjectx) :
               all parameters if par is not specified, are displayed.
 
         """
-        if par == None:
+        if par is None:
             pars = self.pars()
         else :
             pars = list(par)
-        for par in pars:
-            print "%" * 72
-            print "parameter: ", par
-            print "%" * 72
-            self.__ParHandle[par].show()
+        for parname in pars:
+            print("%" * 72)
+            print("parameter: ", parname)
+            print("%" * 72)
+            self.__ParHandle[parname].show()
     #==========================================================================
     # METHOD  : pars
     # PURPOSE : return parameter names
@@ -344,15 +348,15 @@ class Parameters(ItclObjectx) :
 
         **arguments**:
 
-            .. option:: par (string)
+            **par** (str)
 
                  parameter to check
 
-            .. option:: condition (string)
+            **condition** (str)
 
                  parameter condition to check
 
-            .. option:: verbose (bool, default=False)
+            **verbose** (bool, default=False)
 
                  enable or disable verbose mode.
 
@@ -371,7 +375,7 @@ class Parameters(ItclObjectx) :
 
         **arguments**:
 
-            .. option:: condition (string)
+            **condition** (str)
 
                  condition string for filtering parameter set.
 
@@ -390,7 +394,7 @@ class Parameters(ItclObjectx) :
 
         **arguments**:
 
-            .. option:: condition (string)
+            **condition** (str)
 
                  condition string for checking parameter set.
 
@@ -411,11 +415,11 @@ class Parameters(ItclObjectx) :
 
         **arguments**:
 
-            .. option:: par (string)
+            **par** (str)
 
                  parameter name to add.
 
-            .. option:: \*\*kwargs:
+            **\*\*kwargs** (dict):
 
                  <attribute>=<value> specifications for the parameter
 
@@ -440,11 +444,11 @@ class Parameters(ItclObjectx) :
 
         **arguments**:
 
-            .. option:: par (string)
+            **par** (str)
 
                  parameter name to modify.
 
-            .. option:: \*\*kwargs:
+            **\*\*kwargs** (dict)
 
                  <attribute>=<value> specifications for the parameter
 
@@ -456,7 +460,9 @@ class Parameters(ItclObjectx) :
         if not (par in self.pars()) :
             self.warning("parameter \"%s\" not present" % (par))
             return
-        self.__ParHandle[par] = Parameter(par, **kwargs)
+        #self.__ParHandle[par] = Parameter(par, **kwargs)
+        for key, value in list(kwargs.items()) :
+            self.__ParHandle[par][key] = value
     #==========================================================================
     # METHOD  : free_pars
     # PURPOSE : return free parameters
@@ -475,7 +481,7 @@ class Parameters(ItclObjectx) :
     # PURPOSE : return indices of free parameters
     #==========================================================================
     def free_indices(self):
-        """ return list of parameter indices for paramteres that 
+        """ return list of parameter indices for paramteres that
             are free to vary.
 
         **results**:
@@ -498,7 +504,7 @@ class Parameters(ItclObjectx) :
 
         **arguments**:
 
-            .. option:: values (list or tuple, default=None)
+            **values** (list or tuple, default=None)
 
                  list of values to set parameters current value attribute.
                  if values is not specified, return a list of parameter
@@ -513,23 +519,26 @@ class Parameters(ItclObjectx) :
               current values.
 
         """
-        if values != None :
+        if values is not None :
             if len(values) != len(self.pars()) :
                 self.error("number of values != number of parameters")
-                return
+                return None
             free_pars   = self.free_pars()
             tied_pars   = self.list_of_pars("tied")
             untied_pars = self.list_of_pars("untied")
             for par, value in zip(self.pars(), values) :
                 if par in free_pars :
                     self[par] = float(value)
-            if len(tied_pars) > 0 :
+            if tied_pars :
+                dvars = dict(locals())
+                dvars.update(globals())
                 for par in untied_pars :
-                    exec("%s = %s" % (par, self[par]))
+                    dvars[par] = float(self[par])
                 for par in tied_pars :
                     tied_expr = self.__ParHandle[par]["tied"]
-                    exec("value = %s" % (tied_expr))
+                    value = eval(tied_expr, dvars)
                     self[par] = float(value)
+                    dvars[par] = self[par]
         return [self[par] for par in self.pars()]
     #==========================================================================
     # METHOD  : free_values
@@ -542,7 +551,7 @@ class Parameters(ItclObjectx) :
 
         **arguments**:
 
-            .. option:: values (list or tuple, default=None)
+            **values** (list or tuple, default=None)
 
                  list of values to set free parameters current value attribute.
                  if values is not specified, return a list of free parameter
@@ -558,21 +567,24 @@ class Parameters(ItclObjectx) :
 
         """
         free_pars = self.free_pars()
-        if values != None :
+        if values is not None :
             if len(values) != len(free_pars) :
                 self.error("number of values != number of free parameters")
-                return
+                return None
             tied_pars   = self.list_of_pars("tied")
             untied_pars = self.list_of_pars("untied")
             for par, value in zip(free_pars, values) :
                 self[par] = float(value)
-            if len(tied_pars) > 0 :
+            if tied_pars :
+                dvars = dict(locals())
+                dvars.update(globals())
                 for par in untied_pars :
-                    exec("%s = %s" % (par, self[par]))
+                    dvars[par] = float(self[par])
                 for par in tied_pars :
                     tied_expr = self.__ParHandle[par]["tied"]
-                    exec("value = %s" % (tied_expr))
+                    value = eval(tied_expr, dvars)
                     self[par] = float(value)
+                    dvars[par] = self[par]
         return [self[par] for par in free_pars]
     #==========================================================================
     # METHOD  : check_correct_step_limits
