@@ -4,17 +4,17 @@
 # AUTHOR   : Richard Booth
 # DATE     : Sat Nov  9 11:25:14 2013
 # -----------------------------------------------------------------------------
-# NOTES    : 
+# NOTES    :
 #
 # LICENSE  : (BSD-new)
-# 
+#
 # This software is provided subject to the following terms and conditions,
 # which you should read carefully before using the software.  Using this
 # software indicates your acceptance of these terms and conditions.  If you
 # do not agree with these terms and conditions, do not use the software.
-# 
+#
 # Copyright (c) 2013 Richard Booth. All rights reserved.
-# 
+#
 # Redistribution and use in source or binary forms, with or without
 # modifications, are permitted provided that the following conditions are met:
 #     * Redistributions of source code must retain the above copyright
@@ -28,9 +28,9 @@
 #       (those who make changes to the software, documentation or other
 #       materials) may be used to endorse or promote products derived from
 #       this software without specific prior written permission.
-# 
+#
 # Disclaimer
-# 
+#
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, INFRINGEMENT AND THE IMPLIED WARRANTIES OF
 # MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
@@ -43,13 +43,13 @@
 # BUT NOT LIMITED TO, CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 # OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 # ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY
 # FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
 # ARISING OUT OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY
 # DERIVATIVES THEREOF, EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE
@@ -57,43 +57,41 @@
 # NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR
 # MODIFICATIONS.
 ################################################################################
-import user
+from builtins import str
+from builtins import range
 import sys
-import os
-import os.path
-import string
-import re
-import numpy
 import math
-from Tkinter import *
-from decida.PlotBase import PlotBase
+import tkinter as tk
+import six
+from decida.PlotBasem import PlotBasem
 from decida.Data import Data
 from decida.SelectionDialog import SelectionDialog
 
-class SmithChartx(PlotBase) :
-    """ plot s-parameter data on a Smith chart.
-
+class SmithChartx(PlotBasem) :
+    """
     **synopsis**:
 
-    *SmithChartx* plots s-parameter on a Smith chart.  The Smith chart grid is
-    normalized impedance and/or admittance.  The grid can be extended beyond
-    the unit circle.
+        Plot s-parameter data on a Smith chart.
+
+        *SmithChartx* plots s-parameter on a Smith chart.  The Smith chart
+        grid is normalized impedance and/or admittance.  The grid can be
+        extended beyond the unit circle.
 
     **constructor arguments**:
 
-        .. option:: parent (Tkinter handle, default=None)
+        **parent** (tk handle, default=None)
 
               handle of frame or other widget to pack plot in.
               if this is not specified, top-level is created.
 
-        .. option:: \*\*kwargs (dict)
+        **\*\*kwargs** (dict)
 
               keyword=value specifications:
               options or configuration-options
 
     **options**:
 
-        .. option:: command 
+        **command** (list)
 
               list of pairs of data-object, string of freq, RE(s1), IM(s1),
               ?RE(s2), IM(s2), ...?  columns
@@ -111,151 +109,147 @@ class SmithChartx(PlotBase) :
 
     **configuration options**:
 
-        .. option::  verbose (bool, default=False)
+        **verbose** (bool, default=False)
 
               enable/disable verbose mode
 
-        .. option::  title (str, default="")
+        **title** (str, default="")
 
               main title
 
-        .. option::  xtitle (str, default="")
+        **xtitle** (str, default="")
 
               x-axis title
 
-        .. option::  ytitle (str, default="")
+        **ytitle** (str, default="")
 
               y-axis title
 
-        .. option::  plot_height (str, default="10i" for MacOS, else "7i")
+        **plot_height** (str, default="10i" for MacOS, else "7i")
 
               Height of plot window (Tk inch  or pixelspecification)
 
-        .. option::  plot_width  (str, default="10i" for MacOS, else "7i")
+        **plot_width** (str, default="10i" for MacOS, else "7i")
 
               Width of plot window (Tk inch or pixel specification)
 
-        .. option::  plot_background (str, default="GhostWhite")
+        **plot_background** (str, default="GhostWhite")
 
               Background color of plot window
 
-        .. option::  legend_background (str, default="AntiqueWhite2")
+        **legend_background** (str, default="AntiqueWhite2")
 
               Background color of legend
 
-        .. option::  grid_color (str, default="black")
+        **grid_color** (str, default="black")
 
               Color of Smith Chart grid.
 
-        .. option:: unit_color (str, default="#eeeeff")
+        **unit_color** (str, default="#eeeeff")
 
               Color of Smith Chart unit-circle.
 
-        .. option:: unit_width (int, default=4)
+        **unit_width** (int, default=4)
 
               Width of Smith Chart unit-circle outline.
 
-        .. option:: resistance_list (list of floats, default=
-                  0.1, 0.2, 0.3, 0.5, 0.7, 1, 1.5, 2, 3, 5, 10
-              )
+        **resistance_list** (list of float, default=[
+                  0.1, 0.2, 0.3, 0.5, 0.7, 1, 1.5, 2, 3, 5, 10])
 
               list of normalized resistance values to form grid of Smith Chart.
 
-        .. option:: reactance_list (list of floats, default=
-                  0.1, 0.2, 0.3, 0.5, 0.7, 1, 1.5, 2, 3, 5, 10
-              )
+        **reactance_list** (list of float, default=[
+                  0.1, 0.2, 0.3, 0.5, 0.7, 1, 1.5, 2, 3, 5, 10])
 
               list of normalized reactance values to form grid of Smith Chart.
 
-        .. option::  colors (list of str, default =
+        **colors** (list of str, default=[
                 "blue", "red", "green", "orange", "cyan",
                 "brown", "black", "blue violet", "cadet blue",
                 "dark cyan", "dark goldenrod", "dark green",
                 "dark magenta", "dark olive green", "dark orange",
                 "dark red", "dark slate blue", "dark slate gray",
-                "dodger blue", "forest green", "steel blue", "sienna"
-              )
+                "dodger blue", "forest green", "steel blue", "sienna"])
 
               list of colors for curves.
               Used to populate color menu, and to specify curve colors
               in scripted "command" option.
 
-        .. option::  symbols (list of str, default = 
+        **symbols** (list of str, default=[
                 "none", "dot", "square", "diamond",
                 "triangle", "itriangle",
                 "dash", "pipe", "plus", "cross",
                 "spade", "heart", "diam", "club", "shamrock",
-                "fleurdelis", "circle", "star"
-              ) 
+                "fleurdelis", "circle", "star"])
 
               list of symbols for curves.
               Used to populate symbol menu, and to specify curve symbols
               in scripted "command" option.
 
-        .. option::  ssizes (list of floats, default = [0.01])
+        **ssizes** (list of float, default = [0.01])
 
               list of symbol sizes for curves.
               Used to specify curve symbol sizes
               in scripted "command" option.
 
-        .. option::  wlines (list of ints, default = [1])
+        **wlines** (list of int, default = [1])
 
               list of line widths for curves.
               Used to specify curve line widths
               in scripted "command" option.
 
-        .. option::  traces (list, default = ["increasing"])
+        **traces** (list, default = ["increasing"])
 
               list of traces for curves.  each trace can be one of:
               "increasing", "decreasing", or "both".
               Used to specify curve trace directions
               in scripted "command" option.
 
-        .. option::  xaxis (str, default="lin")
+        **xaxis** (str, default="lin")
 
               linear or logarithmic axis: "lin" or "log"
 
-        .. option::  yaxis (str, default="lin")
+        **yaxis** (str, default="lin")
 
               linear or logarithmic axis: "lin" or "log"
 
-        .. option::  xmin  (float, default=0.0)
+        **xmin** (float, default=0.0)
 
               xaxis minimum
 
-        .. option::  xmax  (float, default=0.0)
+        **xmax** (float, default=0.0)
 
               xaxis maximum
 
-        .. option::  ymin  (float, default=0.0)
+        **ymin** (float, default=0.0)
 
               yaxis minimum
 
-        .. option::  ymax  (float, default=0.0)
+        **ymax** (float, default=0.0)
 
               yaxis maximum
 
-        .. option::  grid  (bool, default=True)
+        **grid**  (bool, default=True)
 
-              if true, show grid on plot
+              if True, show grid on plot
 
-        .. option::  legend  (bool, default=True)
+        **legend** (bool, default=True)
 
-              if true, show legend on plot
+              if True, show legend on plot
 
-        .. option::  postscript  (bool, default=False)
+        **postscript** (bool, default=False)
 
               if true, generate a PostScript file.
 
-        .. option::  postscript_file (str, default="plot.ps")
+        **postscript_file** (str, default="plot.ps")
 
               name of PostScript file to plot to
 
-        .. option::  wait (bool, default=False)
+        **wait** (bool, default=False)
 
               wait in main-loop until window is destroyed.
 
-        .. option::  destroy (bool, default=False)
+        **destroy** (bool, default=False)
 
               destroy main window after it has been displayed.
               useful for displaying, generating PostScript, then
@@ -265,7 +259,7 @@ class SmithChartx(PlotBase) :
 
         from decida.Data import Data
         from decida.SmithChartx import SmithChartx
-        
+
         d = Data()
         d.read("spars.col")
         h=SmithChartx(None, command=[d, "freq REAL(Sdd11) IMAG(Sdd11) REAL(Sdd22) IMAG(Sdd22) REAL(Sdd12) IMAG(Sdd12)"], symbols=["dot"])
@@ -274,18 +268,18 @@ class SmithChartx(PlotBase) :
 
         * public methods from *ItclObjectx*
 
-        * public methods from *PlotBase* (2-dimensinal plot base class)
+        * public methods from *PlotBasem* (2-dimensinal plot base class)
 
     """
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # SmithChartx main
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     #==========================================================================
     # METHOD  : __init__
     # PURPOSE : constructor
     #==========================================================================
     def __init__(self, parent=None, **kwargs) :
-        PlotBase.__init__(self, parent=parent)
+        PlotBasem.__init__(self, parent=parent, use_matplotlib=False)
         #----------------------------------------------------------------------
         # private variables:
         #----------------------------------------------------------------------
@@ -313,7 +307,7 @@ class SmithChartx(PlotBase) :
         #----------------------------------------------------------------------
         # keyword arguments are *not* all configuration options
         #----------------------------------------------------------------------
-        for key, value in kwargs.items() :
+        for key, value in list(kwargs.items()) :
             if key == "command" :
                 command = value
             else :
@@ -337,8 +331,8 @@ class SmithChartx(PlotBase) :
                 datobj = item
                 dname = "data_%d" % (idata)
                 i     = 0
-            elif type(item) == str :
-                cols = string.split(item)
+            elif isinstance(item, six.string_types) :
+                cols = item.split()
                 i += 1
                 if i == 1:
                     fcol = cols.pop(0)
@@ -363,22 +357,22 @@ class SmithChartx(PlotBase) :
         #----------------------------------------------------------------------
         self._gui()
         self._mainloop()
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # SmithChartx configuration option callback methods
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # SmithChartx GUI
-    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     #==========================================================================
     # METHOD  : _gui
     # PURPOSE : build graphical user interface
     #==========================================================================
     def _gui(self) :
-        self._Component["smithchart_extended_var"] = IntVar()
+        self._Component["smithchart_extended_var"] = tk.IntVar()
         self._Component["smithchart_extended_var"].set(0)
-        self._Component["smithchart_impedance_var"] = IntVar()
+        self._Component["smithchart_impedance_var"] = tk.IntVar()
         self._Component["smithchart_impedance_var"].set(1)
-        PlotBase._gui(self)
+        PlotBasem._gui(self)
         func0 = self._Component["func0"]
         func1 = self._Component["func1"]
         func0.configure(text="Extended",
@@ -394,9 +388,9 @@ class SmithChartx(PlotBase) :
         for index in range(0, end+1) :
             try :
                 lab = edit_menu.entryconfig(index, "label")[4]
-                if type(lab) is tuple :
-                    lab = string.join(lab)
-                if not lab in keeps :
+                if isinstance(lab, tuple):
+                    lab = " ".join(lab)
+                if lab not in keeps :
                     dels.append(lab)
             except :
                 pass
@@ -430,9 +424,9 @@ class SmithChartx(PlotBase) :
     #==========================================================================
     def _smithchart_text(self, u, v, text, tags) :
         plot = self._Component["plot"]
-        id = plot.create_text(u, v, text=text, tags=tags)
-        plot.create_rectangle(plot.bbox(id), fill="white", outline="white", tags=tags)
-        plot.lift(id)
+        sid = plot.create_text(u, v, text=text, tags=tags)
+        plot.create_rectangle(plot.bbox(sid), fill="white", outline="white", tags=tags)
+        plot.lift(sid)
     #==========================================================================
     # METHOD  : _smithchart_grid
     # PURPOSE : plot smithchart grid
@@ -492,14 +486,14 @@ class SmithChartx(PlotBase) :
             self._smithchart_text(u4, v3, text=str(-x), tags="Y-LABEL")
             self._smithchart_text(u4, v4, text=str(x),  tags="Y-LABEL")
         self._grid_cmd()
-    #===========================================================================
-    # METHOD  : _plot_redraw 
+    #==========================================================================
+    # METHOD  : _plot_redraw
     # PURPOSE : (over-ride) redraw whenever plot limits, curves are changed, etc.
-    #===========================================================================
-    def _plot_redraw(self) :
+    #==========================================================================
+    def _plot_redraw(self, redraw_reason="none") :
         plot = self._Component["plot"]
         self._plot_transform_calc()
-        plot.delete(ALL)
+        plot.delete("all")
         self._plot_title()
         self._smithchart_grid()
         self._grid_cmd()
@@ -515,9 +509,9 @@ class SmithChartx(PlotBase) :
     def _grid_cmd(self) :
         plot = self._Component["plot"]
         if self._Component["grid_var"].get() :
-            plot.itemconfigure("GRID", state=NORMAL)
+            plot.itemconfigure("GRID", state="normal")
         else :
-            plot.itemconfigure("GRID", state=HIDDEN)
+            plot.itemconfigure("GRID", state="hidden")
             return
         extended  = self._Component["smithchart_extended_var"].get()
         impedance = self._Component["smithchart_impedance_var"].get()
@@ -527,27 +521,27 @@ class SmithChartx(PlotBase) :
         plot.itemconfigure("AXIS", width=1, fill=self["grid_color"])
         plot.itemconfigure("AXIS-EXTEND", width=1, fill=self["grid_color"])
         if impedance == 1 :
-            plot.itemconfigure("Z-GRID",  state=NORMAL)
-            plot.itemconfigure("Z-LABEL", state=NORMAL)
-            plot.itemconfigure("Y-GRID",  state=HIDDEN)
-            plot.itemconfigure("Y-LABEL", state=HIDDEN)
+            plot.itemconfigure("Z-GRID",  state="normal")
+            plot.itemconfigure("Z-LABEL", state="normal")
+            plot.itemconfigure("Y-GRID",  state="hidden")
+            plot.itemconfigure("Y-LABEL", state="hidden")
         else :
-            plot.itemconfigure("Z-GRID",  state=HIDDEN)
-            plot.itemconfigure("Z-LABEL", state=HIDDEN)
-            plot.itemconfigure("Y-GRID",  state=NORMAL)
-            plot.itemconfigure("Y-LABEL", state=NORMAL)
+            plot.itemconfigure("Z-GRID",  state="hidden")
+            plot.itemconfigure("Z-LABEL", state="hidden")
+            plot.itemconfigure("Y-GRID",  state="normal")
+            plot.itemconfigure("Y-LABEL", state="normal")
         if extended == 1 :
-            plot.itemconfigure("AXIS-EXTEND", state=NORMAL)
+            plot.itemconfigure("AXIS-EXTEND", state="normal")
             if impedance == 1 :
-                plot.itemconfigure("Z-GRID-EXTEND", state=NORMAL)
-                plot.itemconfigure("Y-GRID-EXTEND", state=HIDDEN)
+                plot.itemconfigure("Z-GRID-EXTEND", state="normal")
+                plot.itemconfigure("Y-GRID-EXTEND", state="hidden")
             else :
-                plot.itemconfigure("Z-GRID-EXTEND", state=HIDDEN)
-                plot.itemconfigure("Y-GRID-EXTEND", state=NORMAL)
+                plot.itemconfigure("Z-GRID-EXTEND", state="hidden")
+                plot.itemconfigure("Y-GRID-EXTEND", state="normal")
         else :
-            plot.itemconfigure("AXIS-EXTEND",   state=HIDDEN)
-            plot.itemconfigure("Z-GRID-EXTEND", state=HIDDEN)
-            plot.itemconfigure("Y-GRID-EXTEND", state=HIDDEN)
+            plot.itemconfigure("AXIS-EXTEND",   state="hidden")
+            plot.itemconfigure("Z-GRID-EXTEND", state="hidden")
+            plot.itemconfigure("Y-GRID-EXTEND", state="hidden")
         plot.lower("UNIT")
         if impedance == 1 :
             plot.lift("Z-LABEL")
@@ -563,8 +557,8 @@ class SmithChartx(PlotBase) :
     def _settings_cmd(self) :
         curve     = self.current_curve()
         wline     = self._curve_wline[curve]
-        rlist     = string.join([str(r) for r in self["resistance_list"]])
-        xlist     = string.join([str(x) for x in self["reactance_list"]])
+        rlist     = " ".join([str(r) for r in self["resistance_list"]])
+        xlist     = " ".join([str(x) for x in self["reactance_list"]])
         #---------------------------------------------------------------------
         # note: all keys must be unique:
         # if type == entry or check:
@@ -574,20 +568,20 @@ class SmithChartx(PlotBase) :
         #---------------------------------------------------------------------
         specs = [
           ["entry", "Titles", [
-                 ["title",  "Main title",   self["title"] ], 
+                 ["title",  "Main title",   self["title"] ],
               ]
           ],
           ["entry", "Colors", [
-                 ["plot_bg",     "plot background",   self["plot_background"] ], 
-                 ["lgnd_bg",     "legend background", self["legend_background"] ], 
-                 ["grid_color",  "grid color",        self["grid_color"] ], 
-                 ["unit_color",  "unit circle color", self["unit_color"] ], 
-                 ["unit_width",  "unit circle width", self["unit_width"] ], 
+                 ["plot_bg",     "plot background",   self["plot_background"] ],
+                 ["lgnd_bg",     "legend background", self["legend_background"] ],
+                 ["grid_color",  "grid color",        self["grid_color"] ],
+                 ["unit_color",  "unit circle color", self["unit_color"] ],
+                 ["unit_width",  "unit circle width", self["unit_width"] ],
               ]
           ],
           ["entry", "Smith Chart:", [
-                 ["rlist",       "resistance list",   rlist], 
-                 ["xlist",       "reactance list",    xlist], 
+                 ["rlist",       "resistance list",   rlist],
+                 ["xlist",       "reactance list",    xlist],
               ]
           ],
           ["entry", "Current Curve: " + curve, [
@@ -595,7 +589,8 @@ class SmithChartx(PlotBase) :
               ]
           ],
         ]
-        sd = SelectionDialog(self, title="Plot Settings", guispecs=specs)
+        top = self._Component["top"]
+        sd = SelectionDialog(top, title="Plot Settings", guispecs=specs)
         V = sd.go()
         if V["ACCEPT"] :
             self["title"]             = V["title"]
@@ -605,7 +600,7 @@ class SmithChartx(PlotBase) :
             self["unit_color"]        = V["unit_color"]
             self["unit_width"]        = V["unit_width"]
             self._curve_wline[curve]  = int(V["wline"])
-            self["resistance_list"]   = [float(r) for r in string.split(V["rlist"])]
-            self["reactance_list"]    = [float(x) for x in string.split(V["xlist"])]
+            self["resistance_list"]   = [float(r) for r in V["rlist"].split()]
+            self["reactance_list"]    = [float(x) for x in V["xlist"].split()]
             # self._smithchart_recalc()
             self._plot_redraw()
