@@ -4,17 +4,17 @@
 # AUTHOR   : Richard Booth
 # DATE     : Sat Nov  9 11:27:24 2013
 # -----------------------------------------------------------------------------
-# NOTES    : 
+# NOTES    :
 #
 # LICENSE  : (BSD-new)
-# 
+#
 # This software is provided subject to the following terms and conditions,
 # which you should read carefully before using the software.  Using this
 # software indicates your acceptance of these terms and conditions.  If you
 # do not agree with these terms and conditions, do not use the software.
-# 
+#
 # Copyright (c) 2013 Richard Booth. All rights reserved.
-# 
+#
 # Redistribution and use in source or binary forms, with or without
 # modifications, are permitted provided that the following conditions are met:
 #     * Redistributions of source code must retain the above copyright
@@ -28,9 +28,9 @@
 #       (those who make changes to the software, documentation or other
 #       materials) may be used to endorse or promote products derived from
 #       this software without specific prior written permission.
-# 
+#
 # Disclaimer
-# 
+#
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, INFRINGEMENT AND THE IMPLIED WARRANTIES OF
 # MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
@@ -43,13 +43,13 @@
 # BUT NOT LIMITED TO, CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 # OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 # ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY
 # FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
 # ARISING OUT OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY
 # DERIVATIVES THEREOF, EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE
@@ -58,25 +58,23 @@
 # MODIFICATIONS.
 ################################################################################
 """ decida procedural simulation python library."""
-import string
+from __future__ import absolute_import
 
-modules = """
-    baseconvert.py
-    interpolate.py
-    lshift.py
-    multiline.py
-    range_sample.py
-    readfile2list.py
-    spice_value.py
-    syscall.py
-    writelist2file.py
-"""
-
-__all__ = []
-for module in string.split(modules, "\n") :
-    module = string.strip(module)
-    if len(module) > 0 :
-        module = string.split(module, ".")
-        module = module[0]
-        __all__.append(module)
-        exec("from " + module + " import " + module)
+__all__ = """
+    baseconvert
+    interpolate
+    multiline
+    range_sample
+    readfile2list
+    spice_value
+    syscall
+    writelist2file
+""".split()
+from .baseconvert    import baseconvert
+from .interpolate    import interpolate
+from .multiline      import multiline
+from .range_sample   import range_sample
+from .readfile2list  import readfile2list
+from .syscall        import syscall
+from .spice_value    import spice_value
+from .writelist2file import writelist2file
