@@ -4,17 +4,17 @@
 # AUTHOR   : Richard Booth
 # DATE     : Sat Nov  9 11:29:37 2013
 # -----------------------------------------------------------------------------
-# NOTES    : 
+# NOTES    :
 #
 # LICENSE  : (BSD-new)
-# 
+#
 # This software is provided subject to the following terms and conditions,
 # which you should read carefully before using the software.  Using this
 # software indicates your acceptance of these terms and conditions.  If you
 # do not agree with these terms and conditions, do not use the software.
-# 
+#
 # Copyright (c) 2013 Richard Booth. All rights reserved.
-# 
+#
 # Redistribution and use in source or binary forms, with or without
 # modifications, are permitted provided that the following conditions are met:
 #     * Redistributions of source code must retain the above copyright
@@ -28,9 +28,9 @@
 #       (those who make changes to the software, documentation or other
 #       materials) may be used to endorse or promote products derived from
 #       this software without specific prior written permission.
-# 
+#
 # Disclaimer
-# 
+#
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, INFRINGEMENT AND THE IMPLIED WARRANTIES OF
 # MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
@@ -43,13 +43,13 @@
 # BUT NOT LIMITED TO, CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 # OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 # ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY
 # FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
 # ARISING OUT OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY
 # DERIVATIVES THEREOF, EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES,
 # INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE
@@ -57,32 +57,39 @@
 # NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR
 # MODIFICATIONS.
 ################################################################################
+from __future__ import print_function
+from builtins import str
+from builtins import range
 from decimal import Decimal
 import random
 
-def range_sample(beg, end, num=0, step=0, mode="lin") :
-    """ lin or log sample a range of values.
+def range_sample(beg, end, num=0, step=0.0, mode="lin") :
+    """
+    **synopsis**:
+
+        lin or log sample a range of values.
 
     **arguments**:
 
-        .. option::  beg (float)
+        **beg** (float)
 
             begin value of the range to sample
 
-        .. option::  end (float)
+        **end** (float)
 
             end value of the range to sample
 
-        .. option::  num (int) (optional, default=0)
+        **num** (int, default=0)
 
             number of points to sample
 
-        .. option::  step=0
+        **step** (float, default=0.0)
 
             step size (lin mode only)
+
             if first step is greater than last step, step down
 
-        .. option::  mode (string) (optional, default="lin")
+        **mode** (str, default="lin")
 
             sweep mode
 
@@ -103,7 +110,7 @@ def range_sample(beg, end, num=0, step=0, mode="lin") :
                 >>> values = decida.range_sample(vmin, vmax, num=11, mode=\"lin\")
                 >>> print values
                 [0.0, 0.2, 0.4, 0.6, 0.8, 1.0, 1.2, 1.4, 1.6, 1.8, 2.0]
-    
+
                 >>> import decida
                 >>> vmin, vmax = 0, 2
                 >>> values = decida.range_sample(vmin, vmax, step=0.5)
@@ -129,11 +136,11 @@ def range_sample(beg, end, num=0, step=0, mode="lin") :
             #---------------------------------------
             for i in range(0, npts) :
                 if ((rng_d > 0) and (val_d > end_d)) or ((rng_d < 0) and (val_d < end_d)) :
-                        break
+                    break
                 values.append(float(val_d))
                 val_d += step_d
         else :
-            print "range_sample: step != 0 only for lin mode"
+            print("range_sample: step != 0 only for lin mode")
     else :
         if   num < 1 :
             pass
@@ -147,11 +154,11 @@ def range_sample(beg, end, num=0, step=0, mode="lin") :
             values = [float(beg_d + i*del_d) for i in range(0, num)]
         elif mode == "log" :
             if   beg == 0 :
-                print "range_sample: beg=0 in log mode"
+                print("range_sample: beg=0 in log mode")
             elif end == 0 :
-                print "range-sample: end=0 in log mode"
+                print("range-sample: end=0 in log mode")
             elif beg*end < 0 :
-                print "range_sample: beg, end have opposite signs in -log mode"
+                print("range_sample: beg, end have opposite signs in -log mode")
             else :
                 base = 1.0*end/beg
                 norm = 1.0/(num-1)
