@@ -1,5 +1,6 @@
 #!/usr/bin/env python
-import user, decida, math
+import math
+import decida
 from decida.Contourx import Contourx
 
 xmin, xmax, ymin, ymax, nx, ny, nc = -20, 20, -20, 20, 41, 41, 41
