@@ -1,12 +1,14 @@
 #!/usr/bin/env python
-import user, decida, math
+import math
+import decida
 from decida.Contourx import Contourx
 
 xmin, xmax, ymin, ymax, nx, ny, nc = -2, 2, -2, 2, 40, 40, 40
 def zfunction(x, y) :
     tx = math.tan(x)
     ty = math.tanh(y)
-    if tx == 0.0 : tx = 1e-12
+    if tx == 0.0 :
+        tx = 1e-12
     return math.atan(ty/tx)
 xvalues = decida.range_sample(xmin, xmax, num=nx)
 yvalues = decida.range_sample(ymin, ymax, num=ny)
