@@ -1,8 +1,10 @@
 #! /usr/bin/env python
+from builtins import range
 import numpy
-import user, decida, decida.test
+import decida
+import decida.test
 from decida.Data      import Data
-from decida.DataViewx import DataViewx
+from decida.DataViewm import DataViewm
 
 def integ_trap_dcd(d, zcol, ycol, xcol):
     d.set("$zcol = integ($ycol, $xcol)")
@@ -40,4 +42,4 @@ d.set("y_integ = (1.0-cos(2*pi*$freq*time))/(2*pi*$freq)")
 integ_trap_dcd(d, "y_trap_dcd", "y", "time")
 integ_trap_npy(d, "y_trap_npy", "y", "time")
 integ_trap_man(d, "y_trap_man", "y", "time")
-DataViewx(data=d, command=[["time y_integ y_trap_dcd y_trap_npy y_trap_man"]])
+DataViewm(data=d, command=[["time y_integ y_trap_dcd y_trap_npy y_trap_man"]])
