@@ -1,10 +1,11 @@
 #!/usr/bin/env python
-import user, decida, decida.test
+import decida
+import decida.test
 from decida.Data import Data
-from decida.DataViewx import DataViewx
+from decida.DataViewm import DataViewm
 
 test_dir = decida.test.test_dir()
 d = Data()
-d.read(test_dir + "lcosc.tr.col")
+d.read(test_dir + "data/lcosc.tr.col")
 dx = d.period_time_average("time", "ivdd", trigger="OUT_DIFF")
-DataViewx(data=dx, command=[["time avg"]])
+DataViewm(data=dx, command=[["time avg"]])
