@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-import user, decida
+from __future__ import print_function
 from decida.EquationParser import EquationParser
 
 eqns = [
@@ -20,8 +20,8 @@ for eqn in eqns :
     lines = ep.parse()
     ivars = ep.ivars()
     del ep
-    print "=" * 72
-    print "equation : ", eqn
-    print "ivars    : ", ivars
+    print("=" * 72)
+    print("equation : ", eqn)
+    print("ivars    : ", ivars)
     for line in lines :
-        print "   %s" % (line)
+        print("   %s" % (line))
