@@ -1,16 +1,17 @@
 #!/usr/bin/env python
-import user, decida, decida.test
+import tkinter as tk
+import decida
+import decida.test
 from decida.FrameNotebook import FrameNotebook
 from decida.TextWindow import TextWindow
-from decida.XYplotx import XYplotx
+from decida.XYplotm import XYplotm
 from decida.Data import Data
-import Tkinter 
 
-fn = FrameNotebook(tab_location="top", destroy=False)
-    
+fn = FrameNotebook(tab_location="top", destroy=True)
+
 f1 = fn.new_page("Page 1")
-b1 = Tkinter.Button(f1, text="Change Tab Location")
-e1 = Tkinter.Entry(f1)
+b1 = tk.Button(f1, text="Change Tab Location")
+e1 = tk.Entry(f1)
 b1.pack()
 e1.pack()
 
@@ -23,8 +24,8 @@ def cmd(self=fn):
 b1["command"] = cmd
 
 f2 = fn.new_page("Page_2")
-b2 = Tkinter.Button(f2, text="Destroy Page 1", command=lambda:f1.destroy())
-b3 = Tkinter.Button(f2, text="Beep",   command=lambda:Tkinter._default_root.bell())
+b2 = tk.Button(f2, text="Destroy Page 1", command=lambda:f1.destroy())
+b3 = tk.Button(f2, text="Beep",   command=lambda:tk._default_root.bell())
 b2.pack()
 b3.pack()
 
@@ -32,8 +33,8 @@ tw = TextWindow(fn.new_page("text"))
 
 test_dir = decida.test.test_dir()
 d = Data()
-d.read(test_dir + "LTspice_ac_ascii.raw")
-XYplotx(fn.new_page("plot"), command=[d, "frequency DB(V(vout1)) PH(V(vout1))"], title="AC analysis", xaxis="log", ymin=-60.0, ymax=0.0, wait=False)
+d.read(test_dir + "data/LTspice/ascii/ac.raw")
+XYplotm(fn.new_page("plot"), command=[d, "frequency DB(V(vout1)) PH(V(vout1))"], title="AC analysis", xaxis="log", ymin=-60.0, ymax=0.0, wait=False)
 
 fn.status("waiting to add new page")
 fn.wait("CONTINUE 1")
@@ -58,4 +59,4 @@ fn.wait("CONTINUE 3")
 fn.status("")
 fn.del_page()
 
-fn.wait("EXIT")
+fn.wait()
