@@ -1,9 +1,11 @@
 #! /usr/bin/env python
-import user, decida, decida.test
+from __future__ import print_function
+import decida
+import decida.test
 from decida.Data import Data
 from decida.LevMar import LevMar
 from decida.Parameters import Parameters
-from decida.XYplotx import XYplotx
+from decida.XYplotm import XYplotm
 
 test_dir = decida.test.test_dir()
 
@@ -31,14 +33,14 @@ parobj = Parameters(specs=(
 ))
 
 dataobj = Data()
-dataobj.read(test_dir + "lcdata.col")
+dataobj.read(test_dir + "data/lcdata.col")
 
 optobj = LevMar(lcfunc, parobj, dataobj,
     meast_col="freq", model_col="fhat", error_col="residual",
     quiet=False, debug=False
 )
 optobj.fit()
-print optobj.status()
-print "parameters = ", parobj.values()
+print(optobj.status())
+print("parameters = ", list(parobj.values()))
 
-XYplotx(command=[dataobj, "vf freq fhat"])
+XYplotm(command=[dataobj, "vf freq fhat"])
