@@ -1,11 +1,12 @@
 #!/usr/bin/env python
-import user, decida, decida.test
+import decida
+import decida.test
 from decida.TextWindow import TextWindow
 
 test_dir = decida.test.test_dir()
-file = test_dir + "TextWindow.txt"
+filename = test_dir + "data/TextWindow.txt"
 twin = TextWindow(text_height=30, wait=False)
-twin.fileread(file)
+twin.fileread(filename)
 twin["text_width"]  = 90
 twin.wait("continue")
 twin.clear()
