@@ -1,5 +1,6 @@
 #!/usr/bin/env python
-import user, decida
+from __future__ import print_function
+import decida
 
 def lev1():
     var1 = "test"
@@ -28,13 +29,13 @@ def lev1():
       var7 = ${var7}_xxx
       var8 = ${var8}_xxx
     """)
-    print "lev1 ctrl = ", ctrl
+    print("lev1 ctrl = ", ctrl)
 
 def lev2():
     ctrl = decida.interpolate("""
       var0 = $var0
     """)
-    print "lev2 ctrl = ", ctrl
+    print("lev2 ctrl = ", ctrl)
 
 var0 = "___"
 var7 = "XXX"
