@@ -1,10 +1,12 @@
 #!/usr/bin/env python
-import user, decida, decida.test
+from __future__ import print_function
+import decida
+import decida.test
 from decida.readfile2list import readfile2list
 
 test_dir = decida.test.test_dir()
-lines = readfile2list(test_dir + "TextWindow.txt")
+lines = readfile2list(test_dir + "data/TextWindow.txt")
 
 for line in lines :
     for uline in decida.multiline(line, 20) :
-        print uline
+        print(uline)
