@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-import user, decida, decida.test
+from __future__ import print_function
 from decida.pattern_alignment import pattern_alignment
 
 map32 = "10000010000101011101101011100101110001110001011010011000001001110111111010000001111110001110010010001110000000010000001110100100"
@@ -9,6 +9,7 @@ map8  = "00100000000001010011011000111001101100010100010110100110010010011101111
 map4  = "100000100001010111011010111001011100011100010110100110000010011101111110100000011111100011100100"
 map2  = "011011010111001010000010000101010100110010010011110001110001011001111100111100100111111010000001"
 
+print("errors: aligned-patterns:")
 pats = [map32, bin32, map16, map8, map4, map2]
 for ab in pattern_alignment(pats) :
-    print ab[1], ab[0]
+    print("%2d %s" % (ab[1], ab[0]))
